@@ -26,13 +26,13 @@ test_that("flsgen_generate", {
   structure <- rflsgen::flsgen_structure(targets_str = json, nb_solutions = 2)
   landscapes <- lapply(structure, rflsgen::flsgen_generate)
   testthat::expect_vector(landscapes, size = 2)
-  testthat::expect_s4_class(landscapes[[1]], class = "RasterLayer")
-  testthat::expect_s4_class(landscapes[[2]], class = "RasterLayer")
+  testthat::expect_s4_class(landscapes[[1]], class = "SpatRaster")
+  testthat::expect_s4_class(landscapes[[2]], class = "SpatRaster")
   testthat::expect_error(rflsgen::flsgen_generate())
   landscapes <- flsgen_generate(structure[[1]], connectivity = 8)
-  testthat::expect_s4_class(landscapes, class = "RasterLayer")
+  testthat::expect_s4_class(landscapes, class = "SpatRaster")
   landscapes <- flsgen_generate(structure[[1]], min_distance = 3)
-  testthat::expect_s4_class(landscapes, class = "RasterLayer")
+  testthat::expect_s4_class(landscapes, class = "SpatRaster")
   landscapes <- flsgen_generate(structure[[1]], min_distance = 3, connectivity = 8)
-  testthat::expect_s4_class(landscapes, class = "RasterLayer")
+  testthat::expect_s4_class(landscapes, class = "SpatRaster")
 })
